"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BabelConfig = void 0;
const lodash_1 = require("lodash");
/**
 * Babel API
 */
class BabelConfig {
    /**
     * Constructor
     */
    constructor(app) {
        this._plugins = {};
        this._presets = {};
        this._enabledPlugins = [];
        this._enabledPresets = [];
        this.app = app;
        this.log = app.logger.instance.scope('@roots/bud-babel');
        this.setPlugin = this.setPlugin.bind(this);
        this.unsetPlugin = this.unsetPlugin.bind(this);
        this.setPluginOptions = this.setPluginOptions.bind(this);
    }
    get app() {
        return this._app();
    }
    set app(app) {
        this._app = app.get;
    }
    get hasProjectConfig() {
        const project = this.app.disk.get('project');
        return (project.has('babel.config.js') || project.has('.babelrc'));
    }
    setPlugin(plugin) {
        this.app.log(`Setting babel plugin: ${plugin}`);
        plugin = lodash_1.isString(plugin) ? [plugin, {}] : plugin;
        this.plugins = Object.assign(Object.assign({}, this.plugins), { [plugin[0]]: plugin });
        return this;
    }
    setPlugins(plugins) {
        this.plugins = plugins.reduce((a, c) => {
            const [plugin, options] = lodash_1.isString(c) ? [c, {}] : c;
            return Object.assign(Object.assign({}, a), { [plugin]: [plugin, options] });
        }, {});
        return this;
    }
    setPreset(preset) {
        preset = lodash_1.isString(preset) ? [preset, {}] : preset;
        this.presets = Object.assign(Object.assign({}, this.presets), { [preset[0]]: preset });
        return this;
    }
    setPresets(presets) {
        this.presets = presets.reduce((a, c) => {
            const [preset, options] = lodash_1.isString(c) ? [c, {}] : c;
            return Object.assign(Object.assign({}, a), { [preset]: [preset, options] });
        }, {});
        return this;
    }
    unsetPreset(preset) {
        if (!this.presets[preset]) {
            this.log.error(`${preset} not found`, this.presets);
        }
        delete this.presets[preset];
    }
    unsetPlugin(plugin) {
        delete this.plugins[plugin];
        return this;
    }
    setPluginOptions(plugin, options) {
        this.plugins[plugin] = [this.plugins[plugin][0], options];
        return this;
    }
    setPresetOptions(preset, options) {
        this.presets[preset] = [this.presets[preset][0], options];
        return this;
    }
    get plugins() {
        this.log.info('Getting babel plugins');
        this.log.debug(this._plugins);
        return this._plugins;
    }
    set plugins(plugins) {
        this.log.info('Setting babel plugins');
        this.log.debug(plugins);
        this._plugins = plugins;
    }
    get presets() {
        this.log.info('Getting babel presets');
        this.log.debug(this._presets);
        return this._presets;
    }
    set presets(presets) {
        this.log.info('Setting babel presets');
        this.log.debug(presets);
        this._presets = presets;
    }
}
exports.BabelConfig = BabelConfig;
//# sourceMappingURL=bud.babel.js.map